@@ -8,10 +8,11 @@
 
 #include "e-diode.h"
 #include "comp2pin.h"
+#include "linkable.h"
 
 class LibraryItem;
 
-class MAINMODULE_EXPORT Diode : public Comp2Pin, public eDiode
+class MAINMODULE_EXPORT Diode : public Comp2Pin, public eDiode, public Linkable
 {
     public:
         Diode( QString type, QString id, bool zener=false );
@@ -20,6 +21,8 @@ class MAINMODULE_EXPORT Diode : public Comp2Pin, public eDiode
  static Component* construct( QString type, QString id );
  static LibraryItem *libraryItem();
 
+        virtual void voltChanged() override;
+
         virtual bool setPropStr( QString prop, QString val ) override;
 
         virtual void initialize() override;
@@ -29,6 +32,8 @@ class MAINMODULE_EXPORT Diode : public Comp2Pin, public eDiode
         virtual double res() override{ return m_resistor->res(); }
         virtual void setResSafe( double resist ) override { m_resistor->setResSafe(resist);}
 
+
+
         virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget ) override;
 
     private:
