@@ -49,7 +49,8 @@ BinCounter::BinCounter( QString type, QString id)
     useSetPin( false );          // Don't use Set Pin
 
     addPropGroup( { tr("Main"), {
-new BoolProp<BinCounter>("Pin_SET",        tr("Use Set Pin")       ,"", this, &BinCounter::pinSet,   &BinCounter::useSetPin ),
+new BoolProp<BinCounter>("Pin_SET", tr("Use Set Pin"),"", this
+                        , &BinCounter::pinSet,&BinCounter::useSetPin, propNoCopy ),
 new BoolProp<BinCounter>("Clock_Inverted", tr("Clock Inverted")    ,"", this, &BinCounter::clockInv, &BinCounter::setClockInv ),
 new BoolProp<BinCounter>("Reset_Inverted", tr("Set/Reset Inverted"),"", this, &BinCounter::srInv,    &BinCounter::setSrInv ),
 new IntProp <BinCounter>("Max_Value",      tr("Count to")          ,"", this, &BinCounter::maxVal,   &BinCounter::setMaxVal,0,"uint" ),
