@@ -25,8 +25,9 @@ ConnBase::ConnBase( QString type, QString id )
     setLabelPos(-16,-44, 0);
 
     addPropGroup( { tr("Main"), {
-new IntProp<ConnBase>( "Size", tr("Size"),"_Pins", this, &ConnBase::size, &ConnBase::setSize,0,"uint" )
-    }, groupNoCopy} );
+        new IntProp<ConnBase>("Size", tr("Size"),"_Pins", this
+                     , &ConnBase::size, &ConnBase::setSize, propNoCopy,"uint" )
+    }, groupNoCopy } );
 }
 ConnBase::~ConnBase()
 {
