@@ -17,7 +17,7 @@ BoolVal::~BoolVal() {;}
 
 void BoolVal::setup( bool )
 {
-    nameLabel->setText( m_property->capt() );
+    trueVal->setText( m_property->capt() );
     m_blocked = true;
 
     bool checked = (m_property->getValStr() == "true");
@@ -30,9 +30,10 @@ void BoolVal::setup( bool )
 void BoolVal::on_trueVal_toggled( bool checked )
 {
     if( m_blocked ) return;
+
+    prepareChange();
     m_property->setValStr( checked ? "true" : "false" );
-    m_propDialog->updtValues();
-    m_propDialog->changed();
+    saveChanges();
 }
 
 void BoolVal::updtValues()
