@@ -51,7 +51,8 @@ class MAINMODULE_EXPORT I51Core : public McuCpu, public eElement
 
             aORIG=1<<4,
             aBIT =1<<5,
-            a16BIT=1<<6
+            a16BIT_LOW=1<<6,
+            a16BIT_HIGH=1<<7
         };
 
         virtual void stamp() override;
@@ -60,6 +61,8 @@ class MAINMODULE_EXPORT I51Core : public McuCpu, public eElement
         virtual void reset() override;
         virtual void runStep() override;
 
+        virtual void INTERRUPT( uint32_t addr ) override;
+
     protected:
 
         uint64_t m_psStep;  // Half Clock cycle ps = 1/24 Machine cycle, = 1/12 Read cycle.
@@ -132,7 +135,9 @@ class MAINMODULE_EXPORT I51Core : public McuCpu, public eElement
         inline void operInd();
         inline void operI08();
         inline void operDir();
-        inline void operRel();
+        inline void operACC();
+        inline void opr2I08();
+        inline void opr2Dir();
 
         inline void addrRgx();
         inline void addrInd();
